/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.explorer.applications');

org.ametys.explorer.applications.Application = function(id, pluginName) 
{
	this._id = id;
	this._pluginName = pluginName;
	this._additionalBtnGroups = [];
};

/**
 * @private
 * @property {String} _id The unique id of the application
 */
org.ametys.explorer.applications.Application.prototype._id;
/**
 * Get the unique id of the application.
 * @returns {String} The unique id of the application.
 */
org.ametys.explorer.applications.Application.prototype.getId = function ()
{
	return this._id;
}

/**
 * @private
 * @property {String} _id The panel the application
 */
org.ametys.explorer.applications.Application.prototype._index;
/**
 * Get the index of the application panel in its parent card panel
 * @returns {Number} The index of the application panel in its parent card panel
 */
org.ametys.explorer.applications.Application.prototype.getIndex = function ()
{
	return this._index;
}
/**
 * Set the index of the application panel in its parent card panel
 * @param {Number} index the index of the application panel in its parent card panel
 */
org.ametys.explorer.applications.Application.prototype.setIndex = function (index)
{
	this._index = index;
}

/**
 * @private
 * @property {String} _pluginName The plugin name of the application
 */
org.ametys.explorer.applications.Application.prototype._pluginName;
/**
 * Get the plugin name of the application.
 * @returns {String} The plugin name of the application.
 */
org.ametys.explorer.applications.Application.prototype.getPluginName = function ()
{
	return this._pluginName;
}

/**
 * @private
 * @property {String} _additionalBtnGroups The additional button for toolbar
 */
org.ametys.explorer.applications.Application.prototype._additionalBtnGroups;

/**
 * Inherit this method to handle additional buttons in toolbar
 * @param {Ext.ButtonGroup} buttonGroup The button group to add
 */
org.ametys.explorer.applications.Application.prototype.addAdditionalToolbarButtonGroup = function (buttonGroup)
{
	this._additionalBtnGroups.push(buttonGroup);
}


/**
 * Inherit this method to create the panel of our application<br/>The purpose of this method is to create the inner panel of the application.
 * @return {Ext.Component} The created panel.
 */
org.ametys.explorer.applications.Application.prototype.createPanel = function () 
{
	throw new "Method createPanel is not implemented on your org.ametys.explorer.applications.Application";
};

/**
 * Inherit this method to create the toolbar of our application<br/>The purpose of this method is to create the toolbar of the application.
 * @return {Ext.Toolbar} The created toolbar.
 */
org.ametys.explorer.applications.Application.prototype.createToolbar = function () 
{
	throw new "Method createToolbar is not implemented on your org.ametys.explorer.applications.Application";
};

/**
 * Determines if the node application can be rename<br/>Inherit this method to allow the renaming.
 */
org.ametys.explorer.applications.Application.prototype.canRenameNode = function () 
{
	return false;
};

/**
 * Refresh the application panel when a node is selected
 * @params {Ext.tree.TreeNode} node The selected node
 */
org.ametys.explorer.applications.Application.prototype.refresh = function (node) 
{
};

/**
 * Executes a command
 * @params {String} cmd The command name to execute, for example 'changeView'
 * @params {Object} args The command arguments. Can be null.
 */
org.ametys.explorer.applications.Application.prototype.execCommand = function (cmd, args) 
{
};

/**
 * Returns a command specific state, for example if the selected view is icons or details.
 * @params {String} cmd The command to query state from. 
 * @params {Object} value The optional value to compare with
 * @return true or false according the command specific state.
 */
org.ametys.explorer.applications.Application.prototype.queryCommandState = function (cmd, value) 
{
};
